Struct aragog::query::JsonQueryResult [−][src]
Result of a succeeded Query. Contains a Vec of serde_json::Value.
The structure has methods to retrieve typed models (get_records).
Fields
documents: Vec<Value>Vector of the returned documents
Implementations
impl JsonQueryResult[src]
pub fn new(documents: Vec<Value>) -> Self[src]
Instantiates a new JsonQueryResult from a document collection
pub fn get_records<T: Record>(&self) -> Vec<DatabaseRecord<T>>[src]
Retrieves deserialized documents from the json results. The documents not matching T will not be returned.
Example
If you want to do a graph query that can return different models you can use this method to retrieve the serialized record:
let json_results = Query::outbound(1, 5, "ChildOf", "User/123").call(&db_accessor).await.unwrap(); let user_results = json_results.get_records::<User>(); let topic_results = json_results.get_records::<Topic>(); let role_results = json_results.get_records::<Role>();
pub fn len(&self) -> usize[src]
Returns the length of documents
pub fn is_empty(&self) -> bool[src]
Returns true if no documents were returned